Vendored from `/home/quinten/docassemble-LITLabTheme/docassemble/LITLabTheme/data/static/`.

Only the assets used by the ALDashboard labeler templates are copied here:
- `bootstrap-theme.css`
- `variables.css`
- `custom.css`
- `dal-favicon.png`